@@ -1,10 +1,12 @@
 #!/usr/bin/env python3
 
+from cmath import e
 from email import message
 from typing import Any, Callable
 from pync import notify  # type: ignore
 import time
 from .classes import NotifyOptions
+from . import logger
 
 
 def call_args_in_subprocess(args: list[str]):
@@ -13,10 +15,19 @@ def call_args_in_subprocess(args: list[str]):
     subprocess.run(args)
 
 
-def macos_say(text: str):
+def say(text: str):
     """speak text with macos say"""
     import subprocess
-    subprocess.run(['say', text])
+    from shutil import which
+    for tts_command in ['say', 'espeak']:
+        if which(tts_command):
+            try:
+                subprocess.run([tts_command], input=text.encode())
+            except Exception as e:
+                logger.error(f'Failed to run {tts_command} <<< "{e}"')
+                logger.exception(e)
+            break
+    # subprocess.run(['say', text])
 
 
 def pync_notify(message: str, title: str = 'Countdown'):
@@ -30,7 +41,7 @@ def no_notify():
 
 
 notify_options_dict = {
-    NotifyOptions.say: macos_say,
+    NotifyOptions.say: say,
     NotifyOptions.pync: pync_notify,
     NotifyOptions.none: no_notify
 }
@@ -38,7 +49,7 @@ notify_options_dict = {
 
 def simple_countdown_notify(length: int,
                             interval: int,
-                            notify: Callable[[str], Any] = macos_say,
+                            notify: Callable[[str], Any] = say,
                             times_up: str = 'Time is up!'):
     """notify user with notify every interval seconds"""
     for i in range(length, 0, -interval):
